%-funksjon som tar inn et sett med feilsensurerte observerte levetider z 
%-simulerer fordelingen til Cramer-von Mises test statisic, under antagelsen
%at z kommer fra en NHPP power law modell. Fordelingen kan simuleres 
%vha en random vektor Uniform(0,1)
%-Returnerer en p-verdi som brukes til  gjre inferens
% angende nullhypotesen
%-gir et plott av simulert fordeling til W^2

function g=f(z,l);
n=length(z);
M=n-1;
t=z(n);     %siste tidspunkt for feil

%finner sufficient statistic
s=sum(log(z(1:M)));
%finer MLE for b
bstar=n/(M*log(t)-s);

%finn test statistic for observert datasett
WData=0;
for i=1:M,
    WData=WData+ ((z(i)/t)^bstar-(2*i-1)/(2*M))^2;
end
WData=WData+1/(12*M)

W=[]; %lagrer hver simulerte verdi av test statistic

%genererer fordeling av test observator vha u
for i=1:l,
    u=rand(1,M);
    u=sort(u);
    k=sum(log(u(1:M)));
    bhat=k/(s-M*log(t));
    
    %finner test statistic Cramer-von Mises
    v=[];
    for i=1:M,
        v(i)=u(i)^(-n/k);   
    end
    w=0;
    for j=1:M,
        w=w+ (v(j)-(2*j-1)/(2*M))^2;
    end
    w=w+1/(12*M);
    
    W=[W w];
end

p=sum(W>WData)/l
%p2=sum(W>0.15)/l

%gir noen strrelser p plottet
figw=7;
figh=5;
fontsa=10;
fonts=15;
posa=[0.12 .11 .86 .86];

%plotter fordeligen til W^2, under power law antakelse for observerte
%feiltider
figure();
hist(W,100);
yl=ylim;
close all

figure();
hold on
set(gcf,'units','centimeters','position',[4 4 figw figh],'paperunits','centimeters','papersize',[figw figh])
set(gca,'fontsize',fontsa,'position',posa)
ylim(yl);
line([WData,WData],[yl],'color','r','linestyle','-')
legend(['w^2_{obs}=' num2str(WData)])
hist(W,100);
line([WData,WData],[yl],'color','r','linestyle','-')
xl=xlim;
xlim([0 xl(2)])
%ylabel('Number of observations')
%xlabel('W^2(T_s)')
hold off
















