%-funksjon som tar inn et sett med feilsensurerte observerte levetider z 
%-simulerer fordelingen til Greenwood test statisic, under antagelsen
%at z kommer fra en NHPP power law modell. Fordelingen kan simuleres 
%vha en random vektor Uniform(0,1)
%-Returnerer en p-verdi som brukes til  gjre inferens
% angende nullhypotesen
%-gir et plott av V* basert p data samt 5 simulerte V*(U)
%-gir et plott av simulert fordeling til G

function p=f(z,l);

close all
n=length(z);
M=n-1;
t=z(n);     %tidspunkt for siste observerte feil

%finner verdi av sufficient statistic
s=sum(log(z(1:M)));

%finn MLE for b, basert p observert datasett
bstar=n/(M*log(t)-s);

%regner ut Greenwood statistic for observerte data
vobs=[];
for i=1:n,
    vobs(i)=(z(i)/t)^bstar;
end
wdata=vobs(1)^2;
for i=1:M,
    wdata=wdata+(vobs(i+1)-vobs(i))^2;
end

W=[]; %lagrer verdi av test statistic for hver sample slik at 
      %et plott av fordelinge til G kan gis

vstar=[]; %tar vare p 5 simulerte V*

%generer fordeling av G vha av u
for i=1:l,
    u=rand(1,M);
    u=sort(u);
    k=sum(log(u(1:M)));
    
    
    
    v=[];
    for j=1:M,
        v(j)=u(j)^(-n/k);   
    end
    v(n)=1;
    
    if i<=5,
        vstar=[vstar;v];
    end
    %regner ut Greenwood test statistic for sample
    w=v(1)^2;
    for j=1:M,
        w=w+ (v(j+1)-v(j))^2;
    end
    W=[W w];
end
%regner ut observert p-verdi
wdata
prob=sum(W>wdata)/l;
prob2=[prob,1-prob];
p=2*(min(prob2));

%gir strrelsen p plott
figw=7;
figh=5;
fontsa=10;
fonts=15;
posa=[0.12 .11 .86 .86];

%gir et plott av fordelingen til Greenwood test statistic
figure();
hist(W,100);
yl=ylim;
close all

figure();
hold on
set(gcf,'units','centimeters','position',[4 4 figw figh],'paperunits','centimeters','papersize',[figw figh])
set(gca,'fontsize',fontsa,'position',posa)
ylim(yl);
line([wdata,wdata],[yl],'color','r','linestyle','-')
legend(['g_{obs}=' num2str(wdata)])
hist(W,100);
line([wdata,wdata],[yl],'color','r','linestyle','-')
xl=xlim;
xlim([0 xl(2)])
wdata
%ylabel('Number of observations')
%xlabel('G')
hold off

%gir et plott av V* for observerte data samt 5 simulerte V*
e=zeros(1,n);
figw=14;
figh=8;
fontsa=10;
fonts=15;
posa=[0.10 .13 .87 .85];

figure();
hold on
set(gcf,'units','centimeters','position',[4 4 figw figh],'paperunits','centimeters','papersize',[figw figh])
set(gca,'fontsize',fontsa,'position',posa)

plot(vobs,e+6,'X',vstar(1,:),e+1,'X',vstar(2,:),e+2,'X',vstar(3,:),e+3,'X',vstar(4,:),e+4,'X',vstar(5,:),e+5,'X','markersize',7,'color',[0 0 0]);
axis([0 1 0 6.05])

set(gca,'ytick',[0 1 2 3 4 5 6],'yticklabel','|V*(U)|V*(U)|V*(U)|V*(U)|V*(U)|V*(T)')
% set(gca,'xtick',[0 1000 2000 3000 4000 5000 6000 7000 8000 8245],'xticklabel','0|1000|2000|3000|4000|5000|6000|7000||8245')
line([0,1],[6,6],'color','r','linestyle','-')
line([0,1],[5,5],'color','b','linestyle','-')
line([0,1],[4,4],'color','b','linestyle','-')
line([0,1],[3,3],'color','b','linestyle','-')
line([0,1],[2,2],'color','b','linestyle','-')
line([0,1],[1,1],'color','b','linestyle','-')
%xlabel('V^{\ast}')
hold off

