%-funksjon som tar inn et sett med feilsensurerte observerte levetider z 
%-simulerer fordelingen til Kolmogorov-Smirnov test statisic, under antagelsen
%at z kommer fra en NHPP power law modell. Fordelingen kan simuleres 
%vha en random vektor Uniform(0,1)
%-Returnerer en p-verdi som brukes til  gjre inferens
% angende nullhypotesen
%-gir et plott av simulert fordeling til D


function g=f(z,l);
n=length(z);
M=n-1;
t=z(n);     %siste tidspunkt for feil

%finner sufficient statistic
s=sum(log(z(1:M)));

%finner b basert p MLE
bstar=n/(M*log(t)-s);

%finner test statistic for datasett
C1=[];
C2=[];
    for i=1:M,
        C1(i)=i/M-(z(i)/t)^bstar;
    end
    for i=1:M,
        C2(i)=(z(i)/t)^bstar-(i-1)/M;
    end
maksD1=max(C1);
maksD2=max(C2);
maksD3=[maksD1 maksD2];
WData=max(maksD3)

W=[];    %tar vare p verdien av simulerte test observatorer

%genererer fordelingen til D vha u
for i=1:l,
    u=rand(1,M);
    u=sort(u);
    k=sum(log(u(1:M)));
    bhat=k/(s-M*log(t));
    
    %finner test statistic Kolmogorov Smirnov
    v=[];
    for i=1:M,
        v(i)=u(i)^(-n/k);   
    end
    D1=[];
    D2=[];
    for j=1:M,
        D1(j)=j/M-v(j);
    end
    for j=1:M,
            D2(j)=v(j)-(j-1)/M;
    end
    maks1=max(D1);
    maks2=max(D2);
    maks3=[maks1 maks2];
    w=max(maks3);
    W=[W w]; 
end

p=sum(W>WData)/l
%p2=sum(W>=0.10)/l

%bestemmer strrelse p plott
figw=7;
figh=5;
fontsa=10;
fonts=15;
posa=[0.12 .11 .86 .86];

%plotter fordelingen til D
figure();
hist(W,100);
yl=ylim;
close all

figure();
hold on
set(gcf,'units','centimeters','position',[4 4 figw figh],'paperunits','centimeters','papersize',[figw figh])
set(gca,'fontsize',fontsa,'position',posa)
ylim(yl);
line([WData,WData],[yl],'color','r','linestyle','-')
legend(['d_{obs}=' num2str(WData)])
hist(W,100);
line([WData,WData],[yl],'color','r','linestyle','-')
xl=xlim;
xlim([0 xl(2)])
%ylabel('Number of observations')
%xlabel('W^2(T_s)')
hold off






