%-funksjon som tar inn et sett med feilsensurerte observerte levetider z 
%-simulerer fordelingen til Kuiper test statisic, under antagelsen
%at z kommer fra en NHPP power law modell. Fordelingen kan simuleres 
%vha en random vektor Uniform(0,1)
%-Returnerer en p-verdi som brukes til  gjre inferens
% angende nullhypotesen
%-gir et plott av simulert fordeling til V

function g=f(z,l);
n=length(z);
M=n-1;
t=z(n);     %siste tidspunkt for feil

%finner sufficient statistic
s=sum(log(z(1:M)));

%finner MLE for b
bstar=n/(M*log(t)-s)

%finner test statistic for datasett
C1=[];
C2=[];
    for i=1:M,
        C1(i)=i/M-(z(i)/t)^bstar;
    end
    for i=1:M,
        C2(i)=(z(i)/t)^bstar-(i-1)/M;
    end
md1=max(C1);
md2=max(C2);
VData=md1+md2

V=[];
%generer fordeling til V vha u
for i=1:l,
    u=rand(1,M);
    u=sort(u);
    k=sum(log(u(1:M)));
    bhat=k/(s-M*log(t));
    
    %finner test statistic basert p Kuiper
    v=[];
    for i=1:M,
        v(i)=u(i)^(-n/k);   
    end
    
    D1=[];
    D2=[];
    for i=1:M,
        D1(i)=i/M-v(i);
    end
    for i=1:M,
        D2(i)=v(i)-(i-1)/M;
    end
    m1=max(D1);
    m2=max(D2);
    V=[V m1+m2];
    
end

p=sum(V>VData)/l
%p1=sum(V>0.412)/l

%bestemmer strrelse p plott
figw=7;
figh=5;
fontsa=10;
fonts=15;
posa=[0.12 .11 .86 .86];

%plotter fordelingen til V
figure();
hist(V,100);
yl=ylim;
close all

figure();
hold on
set(gcf,'units','centimeters','position',[4 4 figw figh],'paperunits','centimeters','papersize',[figw figh])
set(gca,'fontsize',fontsa,'position',posa)
ylim(yl);
line([VData,VData],[yl],'color','r','linestyle','-')
legend(['v_{obs}=' num2str(VData)])
hist(V,100);
line([VData,VData],[yl],'color','r','linestyle','-')
xl=xlim;
xlim([0 xl(2)])
%ylabel('Number of observations')
%xlabel('W^2(T_s)')
hold off

